==> haskell-profunctors-5.2-11-armv7h.pkg.tar.xz: usr/share/haskell/haskell-profunctors/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2
id: profunctors-5.2-026a1eb9905bccdb097d36481584da83
key: profu_C46VciwewvULi7qxLnZUmt
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/profunctors-5.2
hs-libraries: HSprofunctors-5.2-C46VciwewvULi7qxLnZUmt
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
    bifunctors-5.3-b6e9a28a0175204e65003b150c0bbe80
    comonad-5-3b2e208311908bc5a9db1ceb26126917
    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.2-13-armv7h.pkg.tar.xz: usr/share/haskell/haskell-profunctors/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2
id: profunctors-5.2-5f15e32dcb12ed9b3b3c97537d07181e
key: profu_L34BekEuG1sAI4db2hLuRP
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/profunctors-5.2
hs-libraries: HSprofunctors-5.2-L34BekEuG1sAI4db2hLuRP
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
    bifunctors-5.3-bc094c1e88d075fab4936b454b930127
    comonad-5-9b3bac8b2740903020c84a0c2eebf7b2
    contravariant-1.4-1b3716257293d15c38698a7852cba3ac
    distributive-0.5.0.2-77d85d8c453ea57cf04087f9320d2bf7
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
